/* Descriptive Statistics */
/* Measures of Central Tendency, Measures of Spread, and Correlation */

DATA CAREGIVER;
	INPUT ANXIETY DEPRESSION;
	LINES;
		22 16
		12 8
		68 33
		10 6
		5 5
		53 24
		44 18
		37 17
		0 2
		21 14
		64 31
		33 17
		55 30
		18 13
		3 3
		4 4
		11 7
		13 9
		7 5
RUN; 

PROC PRINT DATA=CAREGIVER;
PROC MEANS DATA=CAREGIVER;
PROC CORR DATA=CAREGIVER PLOTS=SCATTER(ELLIPSE=NONE);
RUN;
QUIT;

/************************************************************************************************/

/* Descriptive Statistics */
/* Frequency */

PROC FORMAT;
	VALUE ANX_FMT
		0-9 = '0-9'
		10-19 = '10-19'
		20-29 = '20-29'
		30-39 = '30-39'
		40-49 = '40-49'
		50-59 = '50-59'
		60-69 = '60-69';
	VALUE DEP_FMT
		0-4 = '0-4'
		5-9 = '5-9'
		10-14 = '10-14'
		15-19 = '15-19'
		20-24 = '20-24'
		25-29 = '25-29'
		30-34 = '30-34';
RUN;

PROC FREQ DATA=CAREGIVER;
	FORMAT ANXIETY ANX_FMT.;
	FORMAT DEPRESSION DEP_FMT.;
RUN;

PROC UNIVARIATE DATA=CAREGIVER;
	VAR ANXIETY;
	HISTOGRAM ANXIETY / 
		VSCALE=COUNT
		ENDPOINTS = 0 TO 70 BY 10
		ODSTITLE='Frequency of Anxiety Scores'
		VAXISLABEL='Frequency';
	LABEL ANXIETY='Anxiety';
RUN;

PROC UNIVARIATE DATA=CAREGIVER;
	VAR DEPRESSION;
	HISTOGRAM DEPRESSION / 
		VSCALE=COUNT
		ENDPOINTS = 0 TO 35 BY 5
		ODSTITLE='Frequency of Depression Scores'
		VAXISLABEL='Frequency';
	LABEL DEPRESSION='Depression';
RUN;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* One-Sample t Test */

DATA STUDYHOURS;
	INPUT HOURS;
	LINES;
		6
		9
		12
		3
		11
		10
		18
		9
		13
		8
RUN; 

PROC PRINT DATA=STUDYHOURS;
RUN;

PROC UNIVARIATE DATA=STUDYHOURS;
	VAR HOURS;
	HISTOGRAM HOURS / 
		VSCALE=COUNT
		ENDPOINTS = 0 TO 20 BY 1
		ODSTITLE='Frequency of Study Hours'
		VAXISLABEL='Frequency';
	LABEL HOURS='Hours';
RUN;

PROC TTEST DATA=STUDYHOURS PLOTS(shownull)=interval H0=6.75;
	VAR HOURS;
	TITLE "One-Sample t Test: Study Hours";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Independent t Test */

PROC FORMAT;
	VALUE $TRTMNT_FMT
		"T"="Training"
		"C"="Control";
RUN;

DATA PRODUCTION;
	INPUT TREATMENT $ PRODRATE @@;
	FORMAT TREATMENT $TRTMNT_FMT.;
	LINES;
		T 26 T 45 T 60 T 73 T 45
		T 51 T 63 T 46 T 69 T 51
		T 55 T 58 T 61 T 54 T 64
		T 56 T 59 T 35 T 48 T 45
		T 59 C 44 C 45 C 57 C 28
		C 64 C 39 C 35 C 43 C 21
		C 56 C 22 C 87 C 48 C 12
		C 19 C 62 C 55 C 44 C 39
		C 44 C 57 C 30 C 30
RUN;

PROC PRINT DATA=PRODUCTION;
RUN;

PROC GLM DATA=PRODUCTION PLOTS=DIAGNOSTICS;
	CLASS TREATMENT;
	MODEL PRODRATE=TREATMENT;
	MEANS TREATMENT / HOVTEST=LEVENE(TYPE=ABS);
	TITLE "Independent t Test: Production Rate";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Dependent t Test */

DATA THROWS;
	INPUT THROWS_PRE THROWS_POST @@;
	LINES;
		12 13 15 15 9 11
		16 15 12 15 15 18
		17 17 10 12 12 13
		14 17
RUN;

PROC PRINT DATA=THROWS;
RUN;

PROC MEANS DATA=THROWS;
RUN;

PROC TTEST DATA=THROWS PLOTS(SHOWH0)=INTERVAL;
	PAIRED THROWS_PRE*THROWS_POST;
	TITLE "Dependent t Test: Free Throws";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* One-Way ANOVA */

PROC FORMAT;
	VALUE AGE_FMT
		1="1. Young"
		2="2. Middle-Aged"
		3="3. Elderly";
RUN;

DATA INSURANCE;
	INPUT AGE RATE @@;
	FORMAT AGE AGE_FMT.;
	LINES;
		1 25 1 27 1 23 1 24 1 23 1 24 1 22 1 25 1 21 1 24 1 21 1 23
		2 30 2 29 2 29 2 31 2 28 2 31 2 29 2 32 2 30 2 29 2 28 2 31
		3 25 3 22 3 27 3 23 3 24 3 25 3 23 3 22 3 21 3 22 3 24 3 23
RUN;

PROC PRINT DATA=INSURANCE;
RUN;

PROC GLM DATA=INSURANCE PLOTS=DIAGNOSTICS;
	CLASS AGE;
	MODEL RATE=AGE;
	MEANS AGE / HOVTEST=LEVENE(TYPE=ABS);
	LSMEANS AGE / PDIFF=ALL ADJUST=TUKEY;
	TITLE "One-Way ANOVA: Insurance Response Rate";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Two-Way ANOVA with Nonsignificant Interaction */

PROC FORMAT;
	VALUE PRICE_FMT
		1="1. Regular"
		2="2. Discounted";
  	VALUE LOC_FMT
		1="1. Entrance"
		2="2. Cookie Aisle"
		3="3. Checkout";
RUN;

DATA NEW_COOKIES;
	INPUT PRICE LOCATION SALES @@;
	FORMAT PRICE PRICE_FMT. LOCATION LOC_FMT.;
	LINES;
		1 1 38 1 1 31 1 1 27 1 1 33
		1 2 28 1 2 25 1 2 23 1 2 20
		1 3 21 1 3 32 1 3 30 1 3 22
		2 1 35 2 1 21 2 1 39 2 1 30
		2 2 22 2 2 24 2 2 16 2 2 17
		2 3 19 2 3 15 2 3 25 2 3 20
RUN;

PROC PRINT DATA=NEW_COOKIES;
RUN;

PROC SGPLOT DATA=NEW_COOKIES;
	VLINE PRICE / 
		GROUP=LOCATION
		STAT=MEAN
		RESPONSE=SALES
		MARKERS;
RUN;

PROC GLM DATA=NEW_COOKIES ORDER=INTERNAL;
	CLASS PRICE LOCATION;
	MODEL SALES=PRICE*LOCATION;
	MEANS PRICE*LOCATION / HOVTEST=LEVENE(TYPE=ABS);
	TITLE "Levene's Test of Homogeneity of Variances";
RUN;

PROC GLM DATA=NEW_COOKIES ORDER=INTERNAL;
	CLASS PRICE LOCATION;
	MODEL SALES=PRICE LOCATION PRICE*LOCATION;
	MEANS PRICE LOCATION PRICE*LOCATION;
	LSMEANS LOCATION / PDIFF=ALL ADJUST=TUKEY;
	TITLE "Two-Way ANOVA: Cookie Sales";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Two-Way ANOVA with Significant Interaction */

PROC FORMAT;
	VALUE EXPER_FMT
		1="1. Experienced"
		2="2. Not Experienced";
	VALUE METHOD_FMT
		1="1. In Person"
		2="2. Hybrid"
		3="3. Online";
RUN;

DATA TEACHING_METHODS;
	INPUT EXPERIENCE METHOD SCORE @@;
	FORMAT EXPERIENCE EXPER_FMT. METHOD METHOD_FMT.;
	LINES;
		1 1 57.5 1 1 80.0 1 1 62.5
		1 2 72.5 1 2 75.0
		1 3 77.5 1 3 90.0 1 3 82.5
		2 1 80.0 2 1 65.0 2 1 65.0
		2 2 85.0 2 2 100.0 2 2 87.5
		2 3 57.5 2 3 65.0
RUN;

PROC PRINT DATA=TEACHING_METHODS;
RUN;

PROC SGPLOT DATA=TEACHING_METHODS;
	VLINE METHOD / 
		GROUP=EXPERIENCE
		STAT=MEAN
		RESPONSE=SCORE
		MARKERS;
RUN;

PROC GLM DATA=TEACHING_METHODS ORDER=INTERNAL;
	CLASS EXPERIENCE METHOD;
	MODEL SCORE=EXPERIENCE*METHOD;
	MEANS EXPERIENCE*METHOD / HOVTEST=LEVENE(TYPE=ABS);
	TITLE "Levene's Test of Homogeneity of Variances";
RUN;

PROC GLM DATA=TEACHING_METHODS ORDER=INTERNAL;
	CLASS EXPERIENCE METHOD;
	MODEL SCORE=EXPERIENCE METHOD EXPERIENCE*METHOD;
	MEANS EXPERIENCE METHOD EXPERIENCE*METHOD;
	LSMEANS EXPERIENCE*METHOD / PDIFF=ALL ADJUST=TUKEY;
	TITLE "Two-Way ANOVA: Math Teaching Methods";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* ANCOVA */

PROC FORMAT;
	VALUE REINF_FMT
		1="1. Positive"
		2="2. Negative"
		3="3. None";
RUN;

DATA TARDINESS_REINF;
	INPUT REINF PRE POST @@;
	FORMAT REINF REINF_FMT.;
	LINES;
		1	4	2	1	5	3
		1	6	1	1	7	4
		1	7	3	1	8	5
		1	9	3	1	9	5
		1	10	6	1	11	5
		2	4	3	2	5	5
		2	5	3	2	6	6
		2	7	6	2	8	7
		2	8	6	2	9	8
		2	10	6	2	11	4
		3	5	5	3	5	4
		3	5	4	3	6	8
		3	8	8	3	8	9
		3	9	7	3	10	10
		3	10	8	3	7	10
RUN;

PROC PRINT DATA=TARDINESS_REINF;
RUN;

PROC GLM DATA=TARDINESS_REINF PLOTS=DIAGNOSTICS;
	CLASS REINF;
	MODEL POST=REINF;
	MEANS REINF / HOVTEST=LEVENE(TYPE=ABS);
	TITLE "Levene's Test of Homogeneity of Variances";
RUN;

PROC GLM DATA=TARDINESS_REINF;
	CLASS REINF;
	MODEL POST=REINF PRE REINF*PRE;
	TITLE "Test of Assumption of Homogeneity of Slopes";
RUN;

PROC GLM DATA=TARDINESS_REINF;
	CLASS REINF;
	MODEL POST=REINF PRE;
	TITLE "ANCOVA: Employee Tardiness";
RUN;

PROC GLM DATA=TARDINESS_REINF;
	CLASS REINF;
	MODEL POST=REINF PRE;
	LSMEANS REINF / PDIFF ADJUST=TUKEY;
	TITLE "Adjusted Means & Tukey Post-Hoc Comparisons";
RUN;

PROC GLM DATA=TARDINESS_REINF;
	CLASS REINF;
	MODEL PRE=REINF;
	TITLE "Bryant-Paulson (BP) F Value";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Repeated Measures: One Within Factor Design */

DATA PAPER_COLOR;
	INPUT ID YELLOW GREEN WHITE;
	LINES;
		1	80	76	77
		2	81	89	70
		3	39	64	55
		4	95	93	91
		5	71	90	87
		6	86	76	92
		7	98	94	83
		8	95	92	92
		9	73	77	53
		10	78	88	83
		11	54	64	57
		12	73	92	96
		13	82	75	69
		14	49	67	55
		15	83	91	79
		16	91	90	88
		17	94	97	91
		18	85	89	90
		19	62	69	45
RUN;

PROC PRINT DATA=PAPER_COLOR;
RUN;

PROC MEANS DATA=PAPER_COLOR;
RUN;

PROC GLM DATA=PAPER_COLOR ORDER=INTERNAL;
	MODEL YELLOW GREEN WHITE= / NOUNI;
	REPEATED COLOR / PRINTE;
	TITLE "Repeated Measures ANOVA: Paper Color";
RUN;

TITLE;

PROC FORMAT;
	VALUE COLOR_FMT
		1="Yellow"
		2="Green"
		3="White";
RUN;

DATA PAPER_COLOR_2;
	SET PAPER_COLOR;
	SCORE=YELLOW; COLOR=1; OUTPUT;
	SCORE=GREEN; COLOR=2; OUTPUT;
	SCORE=WHITE; COLOR=3; OUTPUT;
	FORMAT COLOR COLOR_FMT.;
	DROP YELLOW GREEN WHITE;
RUN;

PROC PRINT DATA=PAPER_COLOR_2;
RUN;

PROC SGPANEL DATA=PAPER_COLOR_2;
	PANELBY COLOR / UNISCALE=ROW;
	HISTOGRAM SCORE;
	DENSITY SCORE;
RUN;

PROC GLM DATA=PAPER_COLOR_2 ORDER=INTERNAL PLOTS=DIAGNOSTICS;
	CLASS ID COLOR;
	MODEL SCORE=ID COLOR;
	LSMEANS COLOR / PDIFF CL ADJUST=BON;
	TITLE "Bonferroni Post-Hoc Comparisons";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Repeated Measures: One Within Factor and One Between Factor Design */

PROC FORMAT;
	VALUE ANX_FMT
		1="1. Low Anxiety"
		2="2. High Anxiety";
RUN;

DATA TESTING_TIME;
	INPUT ID ANXIETY TRIAL1 TRIAL2 TRIAL3 TRIAL4;
	FORMAT ANXIETY ANX_FMT.;
	LINES;
		1	1	18	14	12	6
		2	1	19	12	8	4
		3	1	14	10	6	2
		4	1	16	12	10	4
		5	1	12	8	6	2
		6	1	18	10	5	1
		7	2	16	10	8	4
		8	2	18	8	4	1
		9	2	16	12	6	2
		10	2	19	16	10	8
		11	2	16	14	10	9
		12	2	16	12	8	8
RUN;

PROC PRINT DATA=TESTING_TIME;
RUN;

PROC MEANS DATA=TESTING_TIME;
	BY ANXIETY;
RUN;

PROC GLM DATA=TESTING_TIME;
	CLASS ANXIETY;
	MODEL TRIAL1-TRIAL4=ANXIETY / NOUNI;
	MEANS ANXIETY / HOVTEST=LEVENE(TYPE=ABS);
	REPEATED TRIAL / PRINTE;
	LSMEANS ANXIETY / PDIFF CL ADJUST=BON;
	TITLE "Repeated Measures ANOVA: Testing Time";
RUN;

TITLE;

DATA TESTING_TIME_2;
	SET TESTING_TIME;
	SCORE=TRIAL1; TRIAL=1; OUTPUT;
	SCORE=TRIAL2; TRIAL=2; OUTPUT;
	SCORE=TRIAL3; TRIAL=3; OUTPUT;
	SCORE=TRIAL4; TRIAL=4; OUTPUT;
	DROP TRIAL1-TRIAL4;
RUN;

PROC PRINT DATA=TESTING_TIME_2;
RUN;

PROC GLM DATA=TESTING_TIME_2 ORDER=INTERNAL PLOTS=DIAGNOSTICS;
	CLASS ID ANXIETY TRIAL;
	MODEL SCORE=ID ANXIETY TRIAL;
	LSMEANS TRIAL / PDIFF CL ADJUST=BON;
	TITLE "Bonferroni Post-Hoc Comparisons";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Simple Linear Regression */

DATA US_CEREAL;
	INFILE "C:\UScereal.CSV" FIRSTOBS=2 DSD MISSOVER;
	INPUT CEREAL $ MFR $ CALORIES PROTEIN FAT SODIUM 
			FIBER CARBO SUGARS SHELF POTASSIUM VITAMINS $;
	KEEP CALORIES CARBO;
RUN;

PROC PRINT DATA=US_CEREAL;
RUN;

PROC CORR DATA=US_CEREAL PLOTS=SCATTER(ELLIPSE=NONE);
RUN;

PROC GLM DATA=US_CEREAL PLOTS=(DIAGNOSTICS RESIDUALS);
	MODEL CALORIES=CARBO / CLPARM;
	TITLE "Simple Linear Regression: US Cereal";
RUN;

PROC REG DATA=US_CEREAL 
		PLOTS(LABEL)=(COOKSD RSTUDENTBYLEVERAGE DFFITS DFBETAS);
	MODEL CALORIES=CARBO;
	TITLE "Simple Linear Regression: US Cereal";
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Multiple Regression */

DATA PLANT_HEIGHT;
	INFILE "C:\Plant_Height.CSV" FIRSTOBS=2 DSD MISSOVER;
	INPUT SORT_NUMBER SITE GENUS_SPECIES $ FAMILY $ GROWTHFORM $ 
			HEIGHT LOGHT COUNTRY $ SITE_NAME $ LAT LONG ENTERED_BY $
			ALT TEMP DIURN_TEMP ISOTHERM TEMP_SEAS TEMP_MAX_WARM 
			TEMP_MIN_COLD TEMP_ANN_RANGE TEMP_MEAN_WETQR 
			TEMP_MEAN_DRYQR TEMP_MEAN_WARMQR TEMP_MEAN_COLDQR RAIN 
			RAIN_WETM RAIN_DRYM RAIN_SEAS RAIN_WETQR RAIN_DRYQR 
			RAIN_WARMQR RAIN_COLDQR LAI NPP HEMISPHERE;
	KEEP HEIGHT LOGHT TEMP RAIN;
RUN;

PROC PRINT DATA=PLANT_HEIGHT;
RUN;

PROC CORR DATA=PLANT_HEIGHT PLOTS=SCATTER(ELLIPSE=NONE);
RUN;

DATA PLANT_HEIGHT;
	SET PLANT_HEIGHT;
	DROP HEIGHT;
RUN;

PROC PRINT DATA=PLANT_HEIGHT;
RUN;

PROC CORR DATA=PLANT_HEIGHT PLOTS=SCATTER(ELLIPSE=NONE);
RUN;

PROC GLM DATA=PLANT_HEIGHT PLOTS=(DIAGNOSTICS RESIDUALS);
	MODEL LOGHT=TEMP RAIN / CLPARM;
	OUTPUT OUT=INFLUENCE_RESULTS 
			PREDICTED=Y_PRED 
			RESIDUAL=RESID 
			STUDENT=SRESID 
			RSTUDENT=SDRESID 
			H=HAT_H 
			COOKD=COOKS_D 
			DFFITS=DFFITS 
			LCLM=LCL_MEAN 
			UCLM=UCL_MEAN 
			LCL=LCL_INDIVID 
			UCL=UCL_INDIVID 
			PRESS=PRESS;
	TITLE "Multiple Regression: Plant Height";
RUN;

TITLE;

PROC PRINT DATA=INFLUENCE_RESULTS;
RUN;

PROC CORR DATA=INFLUENCE_RESULTS;
	VAR TEMP RAIN RESID;
RUN;

PROC EXPORT DATA=INFLUENCE_RESULTS
	OUTFILE="C:\temp\PlantHeight_Influence.CSV"
	REPLACE;
RUN;

PROC REG DATA=PLANT_HEIGHT 
		PLOTS(LABEL)=(COOKSD RSTUDENTBYLEVERAGE DFFITS DFBETAS);
	MODEL LOGHT=TEMP RAIN / INFLUENCE TOL VIF PARTIAL;
	TITLE "Multiple Regression: Plant Height";
RUN;

TITLE;

DATA PLANT_HEIGHT_2;
	SET PLANT_HEIGHT;
	ID = _N_;
	IF ID=22 OR ID=102 OR ID=146 THEN DELETE;
RUN;

PROC PRINT DATA=PLANT_HEIGHT_2;
RUN;

TITLE;
QUIT;

/************************************************************************************************/

/* Inferential Statistics */
/* Model Building & Variable Selection */

DATA HIGHWAY;
	INFILE "C:\Highway1.CSV" FIRSTOBS=2 DSD MISSOVER;
	INPUT RATE LEN ADT TRKS SIGS1 SLIM SHLD LANE ACPT ITG 
			LWID HTYPE $;
	KEEP RATE ADT TRKS SLIM LANE ACPT;
RUN;

PROC PRINT DATA=HIGHWAY;
RUN;

PROC GLMSELECT DATA=HIGHWAY PLOTS=ALL;
	MODEL RATE=ADT TRKS SLIM LANE ACPT / 
			SELECTION=STEPWISE 
			DETAILS=STEPS 
			SELECT=SL SLSTAY=0.05 SLENTRY=0.05;
	TITLE "Stepwise Model Selection: Highway Accident Rate";
RUN;

PROC GLMSELECT DATA=HIGHWAY PLOTS=ALL;
	MODEL RATE=ADT TRKS SLIM LANE ACPT / 
			SELECTION=FORWARD 
			DETAILS=STEPS 
			SELECT=SL SLENTRY=0.05;
	TITLE "Forward Model Selection: Highway Accident Rate";
RUN;

PROC GLMSELECT DATA=HIGHWAY PLOTS=ALL;
	MODEL RATE=ADT TRKS SLIM LANE ACPT / 
			SELECTION=BACKWARD 
			DETAILS=STEPS 
			SELECT=SL SLSTAY=0.05;
	TITLE "Backward Model Selection: Highway Accident Rate";
RUN;

PROC REG DATA=HIGHWAY PLOTS(ONLY)=(RSQUARE ADJRSQ CP);
	MODEL RATE=ADT TRKS SLIM LANE ACPT / 
			SELECTION=RSQUARE 
			ADJRSQ CP;
	TITLE "All Possible Subsets Analysis: Highway Accident Rate";
RUN;

TITLE;
QUIT;
